require 'spec_helper'
# Pending Ticket ENG-50252
module PricingTest
  describe 'Pricing'  do
    include_context 'request metadata'

# TODO: https://cloudhealthtech.atlassian.net/browse/ZEUS-5915
    it 'Query Price for EDP Customer' do
      pending 'ENG-50252'
      wrap_request do
        variables = {
          'queryReq': {
             'customerId': 57534,
            'payerAccountId': 'ALL',
            'purchaseOption': 'ON_DEMAND',
            'capacityStatus': 'USED',
            'region': 'us-east-1',
            'instanceType': 't2.micro'
          }
        }
        graphql url(service: service),
                format_request(
                  :getAwsEc2Rate,
                  service: service
                ),
                variables, apitest_headers
        expect_success_graphql
        check(:getAwsEc2Rate, service: service)

        # 22% discount for all the line items for the 'RedShirt' customer
        expect(
            json_body[:data][:getAwsEc2Rate].all? do |ec2|
              (100 - (ec2[:discountedRate] / ec2[:publicRate] * 100).round).eql? 22
            end
        ).to be true

        expect_json 'data.getAwsEc2Rate.*',
                    purchaseOption: 'On Demand',
                    locationName: 'us-east-1',
                    instanceType: 't2.micro',
                    offeringClass: nil,
                    leaseContractLength: nil
      end
    end

    it 'Query Price for Non-EDP Customer' do
      # pending ENG-50252
      wrap_request do
        variables = {
            'queryReq': {
                'customerId': 57534,
                'payerAccountId': 'ALL',
                'purchaseOption': 'ON_DEMAND',
                'region': 'ap-south-1',
                'instanceType': 'r5.16xlarge'
            }
        }
        graphql url(service: service),
                format_request(
                    :getAwsEc2Rate,
                    service: service
                ),
                variables, apitest_headers
        expect_success_graphql
        check(:getAwsEc2Rate, service: service)

        # No discount for all the line items for the 'CHT' customer
        expect(
            json_body[:data][:getAwsEc2Rate].all? do |ec2|
              ec2[:discountedRate] == ec2[:publicRate]
            end
        ).to be true

        expect_json 'data.getAwsEc2Rate.*',
                    purchaseOption: 'On Demand',
                    locationName: 'ap-south-1',
                    instanceType: 'r5.16xlarge',
                    offeringClass: nil,
                    leaseContractLength: nil
      end
    end

# TODO: https://cloudhealthtech.atlassian.net/browse/ZEUS-5915

    it 'Query Price for EDP Customer with Payer Account ID' do
      pending 'ENG-50252'
      wrap_request do
        variables = {
            'queryReq': {
                 'customerId': 57534,
                'payerAccountId': 'ALL',
                'purchaseOption': 'ON_DEMAND',
                'region': 'us-west-2',
                'tenancy': 'SHARED',
                "instanceType": 't2.micro'
            }
        }
        graphql url(service: service),
                format_request(
                    :getAwsEc2Rate,
                    service: service
                ),
                variables, apitest_headers
        expect_success_graphql
        check(:getAwsEc2Rate, service: service)

        expect(
            json_body[:data][:getAwsEc2Rate].all? do |ec2|
              (100 - (ec2[:discountedRate] / ec2[:publicRate] * 100).round).eql? 22
            end
        ).to be true

        expect_json 'data.getAwsEc2Rate.*',
                    purchaseOption: 'On Demand',
                    locationName: 'us-west-2',
                    instanceType: 't2.micro',
                    tenancy: 'Shared',
                    offeringClass: nil,
                    leaseContractLength: nil
      end
    end

    it 'Query Price for EDP Customer (SHARED Tenancy)' do
      pending 'ENG-50252'
      wrap_request do
        variables = {
            'queryReq': {
                 'customerId': 57534,
                'payerAccountId': 'ALL',
                'purchaseOption': 'ON_DEMAND',
                'region': 'eu-west-3',
                'tenancy': 'SHARED'
            }
        }
        graphql url(service: service),
                format_request(
                    :getAwsEc2Rate,
                    service: service
                ),
                variables, apitest_headers
        expect_success_graphql
        check(:getAwsEc2Rate, service: service)

        # 22% discount for all the line items for the 'RedShirt' customer
        expect(
            json_body[:data][:getAwsEc2Rate].all? do |ec2|
              (100 - (ec2[:discountedRate] / ec2[:publicRate] * 100).round).eql? 22
            end
        ).to be true

        expect_json 'data.getAwsEc2Rate.*',
                    purchaseOption: 'On Demand',
                    locationName: 'eu-west-3',
                    tenancy: 'Shared',
                    offeringClass: nil,
                    leaseContractLength: nil
      end
    end

# TODO: https://cloudhealthtech.atlassian.net/browse/ZEUS-5915
    it 'Query Price for EDP Customer (DEDICATED Tenancy)' do
      pending 'ENG-50252'
      wrap_request do
        variables = {
            'queryReq': {
                 'customerId': 57534,
                'payerAccountId': 'ALL',
                'purchaseOption': 'ON_DEMAND',
                'region': 'eu-west-3',
                'tenancy': 'DEDICATED'
            }
        }
        graphql url(service: service),
                format_request(
                    :getAwsEc2Rate,
                    service: service
                ),
                variables, apitest_headers
        expect_success_graphql
        check(:getAwsEc2Rate, service: service)

        # 22% discount for all the line items for the 'RedShirt' customer
        expect(
            json_body[:data][:getAwsEc2Rate].all? do |ec2|
              (100 - (ec2[:discountedRate] / ec2[:publicRate] * 100).round).eql? 22
            end
        ).to be true

        expect_json 'data.getAwsEc2Rate.*',
                    purchaseOption: 'On Demand',
                    locationName: 'eu-west-3',
                    tenancy: 'Dedicated',
                    offeringClass: nil,
                    leaseContractLength: nil
      end
    end

    it 'Query Price for EDP Customer (HOST Tenancy)' do
      pending 'ENG-50252'
      wrap_request do
        variables = {
            'queryReq': {
                'customerId': 57534,
                'payerAccountId': 'ALL',
                'purchaseOption': 'ON_DEMAND',
                'region': 'eu-west-3',
                'tenancy': 'HOST',
                'capacityStatus': 'ALLOCATED_HOST'
            }
        }
        graphql url(service: service),
                format_request(
                    :getAwsEc2Rate,
                    service: service
                ),
                variables, apitest_headers
        expect_success_graphql
        check(:getAwsEc2Rate, service: service)

        # 22% discount for all the line items for the 'RedShirt' customer
        expect(
            json_body[:data][:getAwsEc2Rate].all? do |ec2|
              (100 - (ec2[:discountedRate] / ec2[:publicRate] * 100).round).eql? 22
            end
        ).to be true

        expect_json 'data.getAwsEc2Rate.*',
                    purchaseOption: 'On Demand',
                    locationName: 'eu-west-3',
                    tenancy: 'Host',
                    productFamily: 'Dedicated Host',
                    offeringClass: nil,
                    leaseContractLength: nil
      end
    end

    it 'Query Price for EDP Customer (Dedicated HOST Instance)' do
      pending 'ENG-50252'
      wrap_request do
        customer_id = ENV['TEST_ENV'].eql? 'preprod' ? 57534 : 57534
        variables = {
            'queryReq': {
                'customerId': customer_id,
                'payerAccountId': 'ALL',
                'purchaseOption': 'ON_DEMAND',
                'region': 'eu-west-3',
                'tenancy': 'HOST',
                'productFamily': 'Compute Instance'
            }
        }
        graphql url(service: service),
                format_request(
                    :getAwsEc2Rate,
                    service: service
                ),
                variables, apitest_headers
        expect_success_graphql
        check(:getAwsEc2Rate, service: service)

#         Pricing for Windows Server on Dedicated Hosts
#         https://aws.amazon.com/ec2/dedicated-hosts/pricing/#windows-dh
#         expect(
#             json_body[:data][:getAwsEc2Rate].select do |ec2|
#               ec2[:chDerivedOsName] == 'mswin' &&
#                   ec2[:publicRate] > 0
#             end.all? do |ec2|
#               puts ec2[:publicRate], ec2[:discountedRate], ec2[:id]
#               (100 - (ec2[:discountedRate] / ec2[:publicRate] * 100).round).eql? 22
#             end
#         ).to be true
#
#         expect(
#             json_body[:data][:getAwsEc2Rate].reject do |ec2|
#               ec2[:chDerivedOsName] == 'mswin' || ec2[:chDerivedOsName] == 'rhelSQLWeb'
#             end.all? do |ec2|
#               ec2[:publicRate] == 0 && ec2[:discountedRate] == 0
#             end
#         ).to be true

        expect_json 'data.getAwsEc2Rate.*',
                    purchaseOption: 'On Demand',
                    locationName: 'eu-west-3',
                    tenancy: 'Host',
                    productFamily: 'Compute Instance',
                    offeringClass: nil,
                    leaseContractLength: nil
      end
    end

# TODO: https://cloudhealthtech.atlassian.net/browse/ZEUS-5915
    it 'Query Price for EDP Customer (ALLOCATED_CAPACITY_RESERVATION Capacity Status)' do
      pending 'ENG-50252'
      wrap_request do

        customer_id = ENV['TEST_ENV'].eql? 'preprod' ? 57534 : 57534
        variables = {
            'queryReq': {
                'customerId': customer_id ,
                'payerAccountId': 'ALL',
                'purchaseOption': 'ON_DEMAND',
                'region': 'us-west-2',
                'capacityStatus': 'ALLOCATED_CAPACITY_RESERVATION'
            }
        }
        graphql url(service: service),
                format_request(
                    :getAwsEc2Rate,
                    service: service
                ),
                variables, apitest_headers
        expect_success_graphql
        check(:getAwsEc2Rate, service: service)

        expect_json 'data.getAwsEc2Rate.*',
                    purchaseOption: 'On Demand',
                    locationName: 'us-west-2',
                    offeringClass: nil,
                    leaseContractLength: nil
      end
    end
  end
end