require 'spec_helper'

# TODO: update both ECS requests to use a separate request, without having the fields specific to elasticache/redshift
module OnDemandECSPricingTest
  describe 'On Demand ECS Pricing' do
    include_context 'request metadata'
    it 'Query ECS Fargate OD Price for Non-EDP Customer' do
      wrap_request do
        variables = {
          'queryReq': {
            'customerId': 57534,
            'payerAccountId': 'ALL',
            'purchaseOption': 'ON_DEMAND',
            'productCode': 'AmazonECS',
            'productFamily': 'Compute'
          }
        }
        graphql url(service: service),
                format_request(
                  :getAwsLeasableComputeProductRate,
                  service: service
                ),
                variables, apitest_headers
        expect_success_graphql
        check(:getAwsLeasableComputeProductRate, service: service)

        # No discount for all the line items for the 'CHT' customer
        expect(
            json_body[:data][:getAwsLeasableComputeProductRate].all? do |ecs|
              ecs[:discountedRate] == ecs[:publicRate]
            end
        ).to be true

        expect_json 'data.getAwsLeasableComputeProductRate.*',
                    productCode: 'AmazonECS',
                    productFamily: 'Compute',
                    purchaseOption: 'On Demand',
                    description: regex("Fargate|ECS-Anywhere"),
                    leaseContractLength: nil,
                    usageFamily: nil,
                    operation: nil
      end
    end

# TODO: update both ECS requests to use a separate request, without having the fields specific to elasticache/redshift

    it 'Query ECS Compute Metering OD Price for Non-EDP Customer' do
      wrap_request do
        variables = {
            'queryReq': {
                 'customerId': 57534,
                'payerAccountId': 'ALL',
                'purchaseOption': 'ON_DEMAND',
                'productCode': 'AmazonECS',
                'productFamily': 'Compute Metering'
            }
        }
        graphql url(service: service),
                format_request(
                    :getAwsLeasableComputeProductRate,
                    service: service
                ),
                variables, apitest_headers
        expect_success_graphql
        check(:getAwsLeasableComputeProductRate, service: service)

        # No discount for all the line items for the 'CHT' customer
        expect(
            json_body[:data][:getAwsLeasableComputeProductRate].all? do |ecs|
              ecs[:publicRate] == 0
            end
        ).to be true

        expect_json 'data.getAwsLeasableComputeProductRate.*',
                    productCode: 'AmazonECS',
                    productFamily: 'Compute Metering',
                    purchaseOption: 'On Demand',
                    leaseContractLength: nil,
                    usageFamily: nil
      end
    end
  end
end
