require 'spec_helper'

# TODO: Remove tenancy from both requests (use a separate request, apart from the common one)
module OnDemandElastiCachePricingTest
  describe 'On Demand ElastiCache Pricing' do
    include_context 'request metadata'
    it 'Query ElastiCache OD Price for Non-EDP Customer' do
      wrap_request do
        variables = {
          'queryReq': {
            'customerId': 57534,
            'payerAccountId': 'ALL',
            'purchaseOption': 'ON_DEMAND',
            'region': 'us-east-1',
            'productCode': 'AmazonElastiCache',
            'productFamily': 'Cache Instance'
          }
        }
        graphql url(service: service),
                format_request(
                  :getAwsLeasableComputeProductRate,
                  service: service
                ),
                variables, apitest_headers
        expect_success_graphql
        check(:getAwsLeasableComputeProductRate, service: service)

        # No discount for all the line items for the 'CHT' customer
        expect(
            json_body[:data][:getAwsLeasableComputeProductRate].all? do |elasticache|
              elasticache[:discountedRate] == elasticache[:publicRate]
            end
        ).to be true

        expect_json 'data.getAwsLeasableComputeProductRate.*',
                    productCode: 'AmazonElastiCache',
                    productFamily: 'Cache Instance',
                    purchaseOption: 'On Demand',
                    locationName: 'us-east-1',
                    cacheEngine: regex("Memcached|Redis"),
                    offeringClass: nil,
                    leaseContractLength: nil,
                    usageFamily: nil
      end
    end

# TODO: Remove tenancy from both requests (use a separate request, apart from the common one)
    it 'Query ElastiCache OD Price for Non-EDP Customer (cache.t1.micro)' do
      wrap_request do
        variables = {
            'queryReq': {
                'customerId': 57534,
                'payerAccountId': 'ALL',
                'purchaseOption': 'ON_DEMAND',
                'region': 'us-west-1',
                'productCode': 'AmazonElastiCache',
                'productFamily': 'Cache Instance',
                'instanceType': 'cache.t1.micro'
            }
        }
        graphql url(service: service),
                format_request(
                    :getAwsLeasableComputeProductRate,
                    service: service
                ),
                variables, apitest_headers
        expect_success_graphql
        check(:getAwsLeasableComputeProductRate, service: service)

        # No discount for all the line items for the 'CHT' customer
        expect(
            json_body[:data][:getAwsLeasableComputeProductRate].all? do |elasticache|
              elasticache[:discountedRate] == elasticache[:publicRate]
            end
        ).to be true

        expect_json 'data.getAwsLeasableComputeProductRate.*',
                    productCode: 'AmazonElastiCache',
                    productFamily: 'Cache Instance',
                    purchaseOption: 'On Demand',
                    locationName: 'us-west-1',
                    cacheEngine: regex("Memcached|Redis"),
                    instanceType: 'cache.t1.micro',
                    offeringClass: nil,
                    leaseContractLength: nil,
                    usageFamily: nil
      end
    end

#TODO: Uncomment this after fixing cache issues	# TODO: https://cloudhealthtech.atlassian.net/browse/ZEUS-5915
#Commenting it now, as there are no customers using this API ,
#hence commenting this SPEC will not be a problem

# TODO: https://cloudhealthtech.atlassian.net/browse/ZEUS-5915

#     it 'Query ElastiCache OD Price for EDP Customer' do
#       wrap_request do
#         variables = {
#             'queryReq': {
#                  'customerId': 57534,
#                 'payerAccountId': 'ALL',
#                 'purchaseOption': 'ON_DEMAND',
#                 'region': 'us-east-1',
#                 'productCode': 'AmazonElastiCache',
#                 'productFamily': 'Cache Instance'
#             }
#         }
#         graphql url(service: service),
#                 format_request(
#                     :getAwsLeasableComputeProductRate,
#                     service: service
#                 ),
#                 variables, apitest_headers
#         expect_success_graphql
#         check(:getAwsLeasableComputeProductRate, service: service)
#
#         # 22% discount for all the line items for the 'RedShirt' customer
#         expect(
#             json_body[:data][:getAwsLeasableComputeProductRate].all? do |elasticache|
#               (100 - (elasticache[:discountedRate] / elasticache[:publicRate] * 100).round).eql? 22
#             end
#         ).to be true
#
#         expect_json 'data.getAwsLeasableComputeProductRate.*',
#                     productCode: 'AmazonElastiCache',
#                     productFamily: 'Cache Instance',
#                     purchaseOption: 'On Demand',
#                     locationName: 'us-east-1',
#                     cacheEngine: regex("Memcached|Redis"),
#                     offeringClass: nil,
#                     leaseContractLength: nil,
#                     usageFamily: nil
#       end
#     end
  end
end
