require 'spec_helper'

module OnDemandRDSPricingTest
  describe 'On Demand RDS Pricing' do
    include_context 'request metadata'
    it 'Query RDS OD Price for Non-EDP Customer' do
      wrap_request do
        variables = {
          'queryReq': {
            'customerId': 57534,
            'payerAccountId': 'ALL',
            'purchaseOption': 'ON_DEMAND',
            'region': 'us-east-1',
            'instanceType': 'db.t3.micro'
          }
        }
        graphql url(service: service),
                format_request(
                  :getAwsRdsRate,
                  service: service
                ),
                variables, apitest_headers
        expect_success_graphql
        check(:getAwsRdsRate, service: service)

        # No discount for all the line items for the 'CHT' customer
        expect(
            json_body[:data][:getAwsRdsRate].all? do |rds|
              rds[:discountedRate] == rds[:publicRate]
            end
        ).to be true

        expect_json 'data.getAwsRdsRate.*',
                    productCode: 'AmazonRDS',
                    purchaseOption: 'On Demand',
                    locationName: 'us-east-1',
                    instanceType: 'db.t3.micro',
                    offeringClass: nil,
                    leaseContractLength: nil
      end
    end

    it 'Query RDS OD Price for Non-EDP Customer (MariaDB)' do
      wrap_request do
        variables = {
            'queryReq': {
                'customerId': 57534,
                'payerAccountId': 'ALL',
                'purchaseOption': 'ON_DEMAND',
                'region': 'us-west-1',
                'dbEngine': 'MariaDB',
                'instanceType': 'db.m5.large'
            }
        }
        graphql url(service: service),
                format_request(
                    :getAwsRdsRate,
                    service: service
                ),
                variables, apitest_headers
        expect_success_graphql
        check(:getAwsRdsRate, service: service)

        # No discount for all the line items for the 'CHT' customer
        expect(
            json_body[:data][:getAwsRdsRate].all? do |rds|
              rds[:discountedRate] == rds[:publicRate]
            end
        ).to be true

        expect_json 'data.getAwsRdsRate.*',
                    productCode: 'AmazonRDS',
                    purchaseOption: 'On Demand',
                    locationName: 'us-west-1',
                    dbEngine: 'MariaDB',
                    dbEdition: nil,
                    deploymentOption: regex("^Single-AZ|Multi-AZ$"),
                    chDerivedDbName: regex("^MariaDB(\s\\\(Multi-AZ\\\))?$"),
                    licenseModel: 'No license required',
                    offeringClass: nil,
                    leaseContractLength: nil
      end
    end

    it 'Query RDS OD Price for Non-EDP Customer (Aurora MySQL)' do
      wrap_request do
        variables = {
            'queryReq': {
                'customerId': 57534,
                'payerAccountId': 'ALL',
                'purchaseOption': 'ON_DEMAND',
                'region': 'eu-west-3',
                'dbEngine': 'Aurora MySQL',
                'instanceType': 'db.m5.large'
            }
        }
        graphql url(service: service),
                format_request(
                    :getAwsRdsRate,
                    service: service
                ),
                variables, apitest_headers
        expect_success_graphql
        check(:getAwsRdsRate, service: service)

        # No discount for all the line items for the 'CHT' customer
        expect(
            json_body[:data][:getAwsRdsRate].all? do |rds|
              rds[:discountedRate] == rds[:publicRate]
            end
        ).to be true

        expect_json 'data.getAwsRdsRate.*',
                    productCode: 'AmazonRDS',
                    purchaseOption: 'On Demand',
                    locationName: 'eu-west-3',
                    dbEngine: 'Aurora MySQL',
                    dbEdition: nil,
                    deploymentOption: 'Single-AZ',
                    chDerivedDbName: 'Amazon Aurora',
                    licenseModel: 'No license required',
                    offeringClass: nil,
                    leaseContractLength: nil
      end
    end

    it 'Query RDS OD Price for Non-EDP Customer (Aurora PostgreSQL)' do
      wrap_request do
        variables = {
            'queryReq': {
                'customerId': 57534,
                'payerAccountId': 'ALL',
                'purchaseOption': 'ON_DEMAND',
                'region': 'ap-south-1',
                'dbEngine': 'Aurora PostgreSQL',
                'instanceType': 'db.r6i.large'
            }
        }
        graphql url(service: service),
                format_request(
                    :getAwsRdsRate,
                    service: service
                ),
                variables, apitest_headers
        expect_success_graphql
        check(:getAwsRdsRate, service: service)

        # No discount for all the line items for the 'CHT' customer
        expect(
            json_body[:data][:getAwsRdsRate].all? do |rds|
              rds[:discountedRate] == rds[:publicRate]
            end
        ).to be true

        expect_json 'data.getAwsRdsRate.*',
                    productCode: 'AmazonRDS',
                    purchaseOption: 'On Demand',
                    locationName: 'ap-south-1',
                    dbEngine: 'Aurora PostgreSQL',
                    dbEdition: nil,
                    deploymentOption: 'Single-AZ',
                    chDerivedDbName: 'Amazon Aurora PostgreSQL',
                    licenseModel: 'No license required',
                    offeringClass: nil,
                    leaseContractLength: nil
      end
    end

    it 'Query RDS OD Price for Non-EDP Customer (MySQL)' do
      wrap_request do
        variables = {
            'queryReq': {
                'customerId': 57534,
                'payerAccountId': 'ALL',
                'purchaseOption': 'ON_DEMAND',
                'region': 'ca-central-1',
                'dbEngine': 'MySQL',
                'instanceType': 'db.m5.large'
            }
        }
        graphql url(service: service),
                format_request(
                    :getAwsRdsRate,
                    service: service
                ),
                variables, apitest_headers
        expect_success_graphql
        check(:getAwsRdsRate, service: service)

        # No discount for all the line items for the 'CHT' customer
        expect(
            json_body[:data][:getAwsRdsRate].all? do |rds|
              rds[:discountedRate] == rds[:publicRate]
            end
        ).to be true

        expect_json 'data.getAwsRdsRate.*',
                    productCode: 'AmazonRDS',
                    purchaseOption: 'On Demand',
                    locationName: 'ca-central-1',
                    dbEngine: 'MySQL',
                    dbEdition: nil,
                    deploymentOption: regex("^Single-AZ|Multi-AZ$"),
                    chDerivedDbName: regex("^MySQL Community Edition(\s\\\(Multi-AZ\\\))?$"),
                    licenseModel: 'No license required',
                    offeringClass: nil,
                    leaseContractLength: nil
      end
    end

    it 'Query RDS OD Price for Non-EDP Customer (PostgreSQL)' do
      wrap_request do
        variables = {
            'queryReq': {
                'customerId': 57534,
                'payerAccountId': 'ALL',
                'purchaseOption': 'ON_DEMAND',
                'region': 'ap-southeast-1',
                'dbEngine': 'PostgreSQL',
                'instanceType': 'db.m5.large'
            }
        }
        graphql url(service: service),
                format_request(
                    :getAwsRdsRate,
                    service: service
                ),
                variables, apitest_headers
        expect_success_graphql
        check(:getAwsRdsRate, service: service)

        # No discount for all the line items for the 'CHT' customer
        expect(
            json_body[:data][:getAwsRdsRate].all? do |rds|
              rds[:discountedRate] == rds[:publicRate]
            end
        ).to be true

        expect_json 'data.getAwsRdsRate.*',
                    productCode: 'AmazonRDS',
                    purchaseOption: 'On Demand',
                    locationName: 'ap-southeast-1',
                    dbEngine: 'PostgreSQL',
                    dbEdition: nil,
                    deploymentOption: regex("^Single-AZ|Multi-AZ$"),
                    chDerivedDbName: regex("^PostgreSql Community Edition\\\(Beta\\\)(\s\\\(Multi-AZ\\\))?$"),
                    licenseModel: 'No license required',
                    offeringClass: nil,
                    leaseContractLength: nil
      end
    end

    it 'Query RDS OD Price for Non-EDP Customer (Oracle)' do
      wrap_request do
        variables = {
            'queryReq': {
                'customerId': 57534,
                'payerAccountId': 'ALL',
                'purchaseOption': 'ON_DEMAND',
                'region': 'sa-east-1',
                'dbEngine': 'Oracle',
                'instanceType': 'db.m6i.4xlarge'
            }
        }
        graphql url(service: service),
                format_request(
                    :getAwsRdsRate,
                    service: service
                ),
                variables, apitest_headers
        expect_success_graphql
        check(:getAwsRdsRate, service: service)

        # No discount for all the line items for the 'CHT' customer
        expect(
            json_body[:data][:getAwsRdsRate].all? do |rds|
              rds[:discountedRate] == rds[:publicRate]
            end
        ).to be true

        # Check CH Derived DB Name for 'Single-AZ' Deployment Option for Enterprise Edition
        expect(
            json_body[:data][:getAwsRdsRate].select do |rds|
              rds[:dbEdition] == 'Enterprise' && rds[:deploymentOption] == 'Single-AZ'
            end.all? do |rds|
              rds[:chDerivedDbName] == 'Oracle Database Enterprise Edition (BYOL)'
            end
        ).to be true

        # Check CH Derived DB Name for 'Multi-AZ' Deployment Option for Standard Edition Two
        expect(
            json_body[:data][:getAwsRdsRate].select do |rds|
              rds[:dbEdition] == 'Standard Two' &&
              rds[:deploymentOption] == 'Multi-AZ' &&
              rds[:licenseModel] == 'License included'
            end.all? do |rds|
              rds[:chDerivedDbName] == 'Oracle Database Standard Edition Two (Multi-AZ)'
            end
        ).to be true

        expect_json 'data.getAwsRdsRate.*',
                    productCode: 'AmazonRDS',
                    purchaseOption: 'On Demand',
                    locationName: 'sa-east-1',
                    dbEngine: 'Oracle',
                    dbEdition: regex("^(Enterprise|Standard(\s(One|Two))?)$"),
                    deploymentOption: regex("^Single-AZ|Multi-AZ$"),
                    licenseModel: regex("Bring your own license|License included"),
                    offeringClass: nil,
                    leaseContractLength: nil
      end
    end

    it 'Query RDS OD Price for Non-EDP Customer (Microsoft SQL Server Web Edition)' do
      wrap_request do
        variables = {
            'queryReq': {
                'customerId': 57534,
                'payerAccountId': 'ALL',
                'purchaseOption': 'ON_DEMAND',
                'region': 'eu-north-1',
                'dbEngine': 'SQL Server',
                'instanceType': 'db.m5.large'
            }
        }
        graphql url(service: service),
                format_request(
                    :getAwsRdsRate,
                    service: service
                ),
                variables, apitest_headers
        expect_success_graphql
        check(:getAwsRdsRate, service: service)

        # No discount for all the line items for the 'CHT' customer
        expect(
            json_body[:data][:getAwsRdsRate].all? do |rds|
              rds[:discountedRate] == rds[:publicRate]
            end
        ).to be true


        expect_json 'data.getAwsRdsRate.*',
                    productCode: 'AmazonRDS',
                    purchaseOption: 'On Demand',
                    locationName: 'eu-north-1',
                    dbEngine: 'SQL Server',
                    deploymentOption: regex("^Single-AZ|Multi-AZ$"),
                    licenseModel: regex("License included|NA"),
                    offeringClass: nil,
                    leaseContractLength: nil
      end
    end
  end
end
