require 'spec_helper'

module ReservedRDSPricingTest
  describe 'Reserved RDS Pricing' do
    include_context 'request metadata'
    it 'Query RDS All Upfront RI Price for Non-EDP Customer (Oracle)' do
      wrap_request do
        variables = {
            'queryReq': {
                'customerId': 57534,
                'payerAccountId': 'ALL',
                'purchaseOption': 'AWS_ALL_UPFRONT',
                'region': 'us-east-1',
                'instanceType': 'db.m3.large',
                'dbEngine': 'Oracle',
                'deploymentOption': 'Single-AZ'
            }
        }
        graphql url(service: service),
                format_request(
                    :getAwsRdsRate,
                    service: service
                ),
                variables, apitest_headers
        expect_success_graphql
        check(:getAwsRdsRate, service: service)

        # No discount for all the line items for the 'CHT' customer
        expect(
            json_body[:data][:getAwsRdsRate].all? do |rds|
              rds[:discountedRate] == rds[:publicRate]
            end
        ).to be true

        # LineItem which applies reserve instance will have publicRate as 0.0
        expect(
            json_body[:data][:getAwsRdsRate].select do |rds|
              rds[:unit] == 'Hrs'
            end.all? do |rds|
              rds[:publicRate] == 0.0
            end
        ).to be true

        expect_json 'data.getAwsRdsRate.*',
                    productCode: 'AmazonRDS',
                    purchaseOption: 'All Upfront',
                    locationName: 'us-east-1',
                    instanceType: 'db.m3.large',
                    dbEngine: 'Oracle',
                    deploymentOption: 'Single-AZ',
                    licenseModel: regex("Bring your own license|License included"),
                    offeringClass: 'standard',
                    leaseContractLength: regex("^[1,3]$")
      end
    end

    it 'Query RDS Partial Upfront RI Price for Non-EDP Customer (Microsoft SQL Server Standard Edition)' do
      wrap_request do
        variables = {
            'queryReq': {
                'customerId': 57534,
                'payerAccountId': 'ALL',
                'purchaseOption': 'AWS_PARTIAL_UPFRONT',
                'region': 'us-east-1',
                'instanceType': 'db.m5.large',
                'dbEngine': 'SQL Server',
                'deploymentOption': 'Multi-AZ'
            }
        }
        graphql url(service: service),
                format_request(
                    :getAwsRdsRate,
                    service: service
                ),
                variables, apitest_headers
        expect_success_graphql
        check(:getAwsRdsRate, service: service)

        # No discount for all the line items for the 'CHT' customer
        expect(
            json_body[:data][:getAwsRdsRate].all? do |rds|
              rds[:discountedRate] == rds[:publicRate]
            end
        ).to be true

        expect_json 'data.getAwsRdsRate.*',
                    productCode: 'AmazonRDS',
                    purchaseOption: 'Partial Upfront',
                    locationName: 'us-east-1',
                    instanceType: 'db.m5.large',
                    dbEngine: 'SQL Server',
                    dbEdition: 'Standard',
                    deploymentOption: 'Multi-AZ',
                    licenseModel: 'License included',
                    offeringClass: 'standard',
                    leaseContractLength: 1,
                    chDerivedDbName: 'Microsoft SQL Server Standard Edition (Multi-AZ)'
      end
    end

    it 'Query RDS No Upfront RI Price for Non-EDP Customer (Aurora MySQL)' do
      wrap_request do
        variables = {
            'queryReq': {
                'customerId': 57534,
                'payerAccountId': 'ALL',
                'purchaseOption': 'AWS_NO_UPFRONT',
                'region': 'us-east-1',
                'instanceType': 'db.r3.xlarge',
                'dbEngine': 'Aurora MySQL'
            }
        }
        graphql url(service: service),
                format_request(
                    :getAwsRdsRate,
                    service: service
                ),
                variables, apitest_headers
        expect_success_graphql
        check(:getAwsRdsRate, service: service)

        # No discount for all the line items for the 'CHT' customer
        expect(
            json_body[:data][:getAwsRdsRate].all? do |rds|
              rds[:discountedRate] == rds[:publicRate]
            end
        ).to be true

        expect_json 'data.getAwsRdsRate.*',
                    productCode: 'AmazonRDS',
                    purchaseOption: 'No Upfront',
                    locationName: 'us-east-1',
                    instanceType: 'db.r3.xlarge',
                    dbEngine: 'Aurora MySQL',
                    dbEdition: nil,
                    deploymentOption: 'Single-AZ',
                    licenseModel: 'No license required',
                    offeringClass: 'standard',
                    leaseContractLength: 1,
                    chDerivedDbName: 'Amazon Aurora'
      end
    end
  end
end
