require 'spec_helper'

module SavingsPlansEC2PricingTest
  describe 'Savings Plans EC2 Pricing' do
    include_context 'request metadata'
    it 'Query ComputeSavingsPlans Price with SKU Filters (both sku and discountedSku)' do
      wrap_request do
        variables = {
          'queryReq': {
            'customerId': 57534,
            'payerAccountId': 'ALL',
            'discountedProductCode': 'AmazonEC2',
            'purchaseOption': 'AWS_ALL_UPFRONT',
            'productFamily': 'ComputeSavingsPlans',
            'sku': '8GU23DFTKP2N43SD',
            'discountedSku': '222ZN72EQSMT9B4R'
          }
        }
        graphql url(service: service),
                format_request(
                  :getSavingsPlanProductRates,
                  service: service
                ),
                variables, apitest_headers
        expect_success_graphql
        check(:getSavingsPlanProductRates, service: service)

        # No discount for all the line items for the 'CHT' customer
        expect(
            json_body[:data][:getSavingsPlanProductRates].all? do |sp|
              sp[:discountedRate] == sp[:publicRate]
            end
        ).to be true

        # TITANS-613
        expect_json 'data.getSavingsPlanProductRates.*',
                    purchaseOption: 'All Upfront',
                    locationName: 'us-east-1',
                    sku: '8GU23DFTKP2N43SD',
                    discountedSku: '222ZN72EQSMT9B4R',
                    discountedProductCode: 'AmazonEC2',
                    productCode: 'ComputeSavingsPlans',
                    productFamily: 'ComputeSavingsPlans',
                    usageType: 'ComputeSP:1yrAllUpfront',
                    operation: nil,
                    offeringClass: nil,
                    leaseContractLength: 1
      end
    end

    it 'Query ComputeSavingsPlans Price with multiple purchase options' do
      wrap_request do
        variables = {
            'queryReq': {
                'customerId': 57534,
                'payerAccountId': 'ALL',
                'discountedProductCode': 'AmazonEC2',
                'purchaseOption': [
                    'AWS_ALL_UPFRONT',
                    'AWS_NO_UPFRONT',
                    'AWS_PARTIAL_UPFRONT'
                ],
                'productFamily': 'ComputeSavingsPlans',
                'discountedSku': '222ZN72EQSMT9B4R'
            }
        }
        graphql url(service: service),
                format_request(
                    :getSavingsPlanProductRates,
                    service: service
                ),
                variables, apitest_headers
        expect_success_graphql
        check(:getSavingsPlanProductRates, service: service)

        # No discount for all the line items for the 'CHT' customer
        expect(
            json_body[:data][:getSavingsPlanProductRates].all? do |sp|
              sp[:discountedRate] == sp[:publicRate]
            end
        ).to be true

        # TITANS-613
        expect_json 'data.getSavingsPlanProductRates.*',
                    purchaseOption: regex("All Upfront|Partial Upfront|No Upfront"),
                    locationName: 'us-east-1',
                    discountedSku: '222ZN72EQSMT9B4R',
                    discountedProductCode: 'AmazonEC2',
                    productCode: 'ComputeSavingsPlans',
                    productFamily: 'ComputeSavingsPlans',
                    operation: nil,
                    offeringClass: nil,
                    leaseContractLength: regex("^[1,3]$")
      end
    end

    it 'Query EC2InstanceSavingsPlans Price with SKU Filters (both sku and discountedSku)' do
      wrap_request do
        variables = {
            'queryReq': {
                'customerId': 57534,
                'payerAccountId': 'ALL',
                'discountedProductCode': 'AmazonEC2',
                'purchaseOption': 'AWS_NO_UPFRONT',
                'productFamily': 'EC2InstanceSavingsPlans',
                'sku': 'JT55KFTPGNQREEZP',
                'discountedSku': 'QXBANRT528N3AX2R'
            }
        }
        graphql url(service: service),
                format_request(
                    :getSavingsPlanProductRates,
                    service: service
                ),
                variables, apitest_headers
        expect_success_graphql
        check(:getSavingsPlanProductRates, service: service)

        # No discount for all the line items for the 'CHT' customer
        expect(
            json_body[:data][:getSavingsPlanProductRates].all? do |sp|
              sp[:discountedRate] == sp[:publicRate]
            end
        ).to be true

        expect_json 'data.getSavingsPlanProductRates.*',
                    purchaseOption: 'No Upfront',
                    locationName: 'us-east-1',
                    sku: 'JT55KFTPGNQREEZP',
                    discountedSku: 'QXBANRT528N3AX2R',
                    discountedProductCode: 'AmazonEC2',
                    productCode: 'ComputeSavingsPlans',
                    productFamily: 'EC2InstanceSavingsPlans',
                    usageType: 'EC2SP:m5ad.3yrNoUpfront',
                    operation: nil,
                    offeringClass: nil,
                    leaseContractLength: 3
      end
    end

    it 'Query EC2InstanceSavingsPlans Price with multiple purchase options' do
      wrap_request do
        variables = {
            'queryReq': {
                'customerId': 57534,
                'payerAccountId': 'ALL',
                'discountedProductCode': 'AmazonEC2',
                'purchaseOption': [
                    'AWS_ALL_UPFRONT',
                    'AWS_NO_UPFRONT',
                    'AWS_PARTIAL_UPFRONT'
                ],
                'productFamily': 'EC2InstanceSavingsPlans',
                'discountedSku': 'QXBANRT528N3AX2R'
            }
        }
        graphql url(service: service),
                format_request(
                    :getSavingsPlanProductRates,
                    service: service
                ),
                variables, apitest_headers
        expect_success_graphql
        check(:getSavingsPlanProductRates, service: service)

        # No discount for all the line items for the 'CHT' customer
        expect(
            json_body[:data][:getSavingsPlanProductRates].all? do |sp|
              sp[:discountedRate] == sp[:publicRate]
            end
        ).to be true

        expect_json 'data.getSavingsPlanProductRates.*',
                    purchaseOption: regex("All Upfront|Partial Upfront|No Upfront"),
                    locationName: 'us-east-1',
                    discountedSku: 'QXBANRT528N3AX2R',
                    discountedProductCode: 'AmazonEC2',
                    productCode: 'ComputeSavingsPlans',
                    productFamily: 'EC2InstanceSavingsPlans',
                    operation: nil,
                    offeringClass: nil,
                    leaseContractLength: regex("^[1,3]$")
      end
    end
  end
end
