require 'spec_helper'

module SavingsPlansECSPricingTest
  describe 'Savings Plans ECS Pricing' do
    include_context 'request metadata'
    it 'Query ComputeSavingsPlans Price with SKU Filters (both sku and discountedSku)' do
      wrap_request do
        variables = {
          'queryReq': {
            'customerId': 57534,
            'payerAccountId': 'ALL',
            'discountedProductCode': 'AmazonECS',
            'purchaseOption': 'AWS_ALL_UPFRONT',
            'productFamily': 'ComputeSavingsPlans',
            'sku': '8GU23DFTKP2N43SD',
            'discountedSku': '8CESGAFWKAJ98PME'
          }
        }
        graphql url(service: service),
                format_request(
                  :getSavingsPlanProductRates,
                  service: service
                ),
                variables, apitest_headers
        expect_success_graphql
        check(:getSavingsPlanProductRates, service: service)

        # No discount for all the line items for the 'CHT' customer
        expect(
            json_body[:data][:getSavingsPlanProductRates].all? do |sp|
              sp[:discountedRate] == sp[:publicRate]
            end
        ).to be true

        # TITANS-613
        expect_json 'data.getSavingsPlanProductRates.*',
                    purchaseOption: 'All Upfront',
                    locationName: 'us-east-1',
                    sku: '8GU23DFTKP2N43SD',
                    discountedSku: '8CESGAFWKAJ98PME',
                    discountedProductCode: 'AmazonECS',
                    discountedOperation: nil,
                    productCode: 'ComputeSavingsPlans',
                    productFamily: 'ComputeSavingsPlans',
                    usageType: 'ComputeSP:1yrAllUpfront',
                    operation: nil,
                    offeringClass: nil,
                    leaseContractLength: 1
      end
    end

    it 'Query ComputeSavingsPlans Price with multiple purchase options' do
      wrap_request do
        variables = {
            'queryReq': {
                'customerId': 57534,
                'payerAccountId': 'ALL',
                'discountedProductCode': 'AmazonECS',
                'purchaseOption': [
                    'AWS_ALL_UPFRONT',
                    'AWS_NO_UPFRONT',
                    'AWS_PARTIAL_UPFRONT'
                ],
                'productFamily': 'ComputeSavingsPlans',
                'discountedSku': 'PBZNQUSEXZUC34C9'
            }
        }
        graphql url(service: service),
                format_request(
                    :getSavingsPlanProductRates,
                    service: service
                ),
                variables, apitest_headers
        expect_success_graphql
        check(:getSavingsPlanProductRates, service: service)

        # No discount for all the line items for the 'CHT' customer
        expect(
            json_body[:data][:getSavingsPlanProductRates].all? do |sp|
              sp[:discountedRate] == sp[:publicRate]
            end
        ).to be true

        # TITANS-613
        expect_json 'data.getSavingsPlanProductRates.*',
                    purchaseOption: regex("All Upfront|Partial Upfront|No Upfront"),
                    locationName: 'us-east-1',
                    discountedSku: 'PBZNQUSEXZUC34C9',
                    discountedProductCode: 'AmazonECS',
                    discountedOperation: nil,
                    productCode: 'ComputeSavingsPlans',
                    productFamily: 'ComputeSavingsPlans',
                    operation: nil,
                    offeringClass: nil,
                    leaseContractLength: regex("^[1,3]$")
      end
    end

    it 'E: Query EC2InstanceSavingsPlans Price with SKU Filters (both sku and discountedSku)' do
      wrap_request do
        variables = {
            'queryReq': {
                'customerId': 57534,
                'payerAccountId': 'ALL',
                'discountedProductCode': 'AmazonECS',
                'purchaseOption': 'AWS_NO_UPFRONT',
                'productFamily': 'EC2InstanceSavingsPlans',
                'sku': '8GU23DFTKP2N43SD',
                'discountedSku': '8CESGAFWKAJ98PME'
            }
        }
        graphql url(service: service),
                format_request(
                    :getSavingsPlanProductRates,
                    service: service
                ),
                variables, apitest_headers
        expect_error_graphql(
                    status: 200,
                    errors: [{ message: '[EC2InstanceSavingsPlans is not a valid product family for AmazonECS savings plan]' }]
                )
      end
    end

    it 'E: Query EC2InstanceSavingsPlans Price with multiple purchase options' do
      wrap_request do
        variables = {
            'queryReq': {
                'customerId': 57534,
                'payerAccountId': 'ALL',
                'discountedProductCode': 'AmazonECS',
                'purchaseOption': [
                    'AWS_ALL_UPFRONT',
                    'AWS_NO_UPFRONT',
                    'AWS_PARTIAL_UPFRONT'
                ],
                'productFamily': 'EC2InstanceSavingsPlans',
                'discountedSku': 'PBZNQUSEXZUC34C9'
            }
        }
        graphql url(service: service),
                format_request(
                    :getSavingsPlanProductRates,
                    service: service
                ),
                variables, apitest_headers
        expect_error_graphql(
                    status: 200,
                    errors: [{ message: '[EC2InstanceSavingsPlans is not a valid product family for AmazonECS savings plan]' }]
                )
      end
    end
  end
end
